@@ -64,6 +64,7 @@ package App::Greple::dig;
 __DATA__
 
 expand is_repository	( -name .git -o -name .svn -o -name RCS -o -name CVS )
+expand is_environment	( -name .vscode )
 expand is_temporary	( -name .build -o -name _build )
 expand is_dots		  -name .*
 expand is_version	  -name *,v
@@ -85,7 +86,7 @@ expand is_others	( -name *.bundle -o -name *.dylib -o -name *.o -o \
 option --dig -Mfind \
 	$<move> \
 	( \
-		( is_repository -o is_temporary ) \
+		( is_repository -o is_environment -o is_temporary ) \
 		-prune -o \
 		-type f \
 	) \
